==> haskell-aeson-pretty-0.8.2-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.8.2
id: aeson-pretty-0.8.2-1W38D1vJ1CO5l4dXZsBX6X
key: aeson-pretty-0.8.2-1W38D1vJ1CO5l4dXZsBX6X
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
abi: 2692be2ced57ff959a63d6e155b38384
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-pretty-0.8.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-pretty-0.8.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/aeson-pretty-0.8.2
hs-libraries: HSaeson-pretty-0.8.2-1W38D1vJ1CO5l4dXZsBX6X
depends:
    aeson-1.0.2.1-9juLbWuUPUaFK1txzTGd5H base-4.9.0.0
    base-compat-0.9.2-81oZ9t87zdcD9ZlnIVKnPd bytestring-0.10.8.1
    scientific-0.3.4.10-HyvEaD9RF3TGwvwmkJHXws
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.8.2-16-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.8.2
id: aeson-pretty-0.8.2-7UkabuowHZ1Gv0jn25FiWc
key: aeson-pretty-0.8.2-7UkabuowHZ1Gv0jn25FiWc
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
abi: a0ef430401d8fd7338ad2fe1b3bc6dad
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-pretty-0.8.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-pretty-0.8.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/aeson-pretty-0.8.2
hs-libraries: HSaeson-pretty-0.8.2-7UkabuowHZ1Gv0jn25FiWc
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
